summaryrefslogtreecommitdiff
path: root/community/sxiv/config.h
diff options
context:
space:
mode:
authorroot <root@rshg054.dnsready.net>2013-04-02 00:05:43 -0700
committerroot <root@rshg054.dnsready.net>2013-04-02 00:05:43 -0700
commitc9738c6a1d438f30dfa7363aa847343754f953ac (patch)
tree4922cc79f6695dbe35bdc4ce2c44a7a8d93cf053 /community/sxiv/config.h
parentc623429f33c434cb1cb11974d9e71f48dd5a881f (diff)
Tue Apr 2 00:05:43 PDT 2013
Diffstat (limited to 'community/sxiv/config.h')
-rw-r--r--community/sxiv/config.h46
1 files changed, 21 insertions, 25 deletions
diff --git a/community/sxiv/config.h b/community/sxiv/config.h
index cc95fd46a..cd89b5fac 100644
--- a/community/sxiv/config.h
+++ b/community/sxiv/config.h
@@ -1,15 +1,3 @@
-#ifdef _FEATURE_CONFIG
-
-/* auto-orientate jpeg files according to their exif tags?
- * (requires libexif [-lexif] to be installed)
- */
-#define EXIF_SUPPORT 1
-/* load all frames from gif files and support gif animations?
- * (requires giflib [-lgif] to be installed)
- */
-#define GIF_SUPPORT 1
-
-#endif
#ifdef _WINDOW_CONFIG
/* default window dimensions (overwritten via -g option): */
@@ -18,11 +6,19 @@ enum {
WIN_HEIGHT = 600
};
-/* default color for window background: */
-static const char * const BG_COLOR = "#777777";
-/* default color for thumbnail selection: */
-static const char * const SEL_COLOR = "#DDDDDD";
-/* (see X(7) section "COLOR NAMES" for valid values) */
+/* bar font:
+ * (see X(7) section "FONT NAMES" for valid values)
+ */
+static const char * const BAR_FONT = "-*-fixed-medium-r-*-*-13-*-*-*-*-60-*-*";
+
+/* colors:
+ * (see X(7) section "COLOR NAMES" for valid values)
+ */
+static const char * const WIN_BG_COLOR = "#777777";
+static const char * const WIN_FS_COLOR = "#000000";
+static const char * const SEL_COLOR = "#DDDDDD";
+static const char * const BAR_BG_COLOR = "#222222";
+static const char * const BAR_FG_COLOR = "#EEEEEE";
#endif
#ifdef _IMAGE_CONFIG
@@ -43,9 +39,6 @@ static const float zoom_levels[] = {
100.0, 150.0, 200.0, 400.0, 800.0
};
-/* default slideshow delay (in sec, overwritten via -S option): */
-enum { SLIDESHOW_DELAY = 5 };
-
/* default settings for multi-frame gif images: */
enum {
GIF_DELAY = 100, /* delay time (in ms) */
@@ -68,8 +61,10 @@ static const keymap_t keys[] = {
{ false, XK_q, it_quit, (arg_t) None },
{ false, XK_Return, it_switch_mode, (arg_t) None },
{ false, XK_f, it_toggle_fullscreen, (arg_t) None },
+ { false, XK_b, it_toggle_bar, (arg_t) None },
{ false, XK_r, it_reload_image, (arg_t) None },
+ { false, XK_R, t_reload_all, (arg_t) None },
{ false, XK_D, it_remove_image, (arg_t) None },
{ false, XK_n, i_navigate, (arg_t) +1 },
@@ -78,6 +73,7 @@ static const keymap_t keys[] = {
{ false, XK_BackSpace, i_navigate, (arg_t) -1 },
{ false, XK_bracketright, i_navigate, (arg_t) +10 },
{ false, XK_bracketleft, i_navigate, (arg_t) -10 },
+ { true, XK_6, i_alternate, (arg_t) None },
{ false, XK_g, it_first, (arg_t) None },
{ false, XK_G, it_n_or_last, (arg_t) None },
@@ -113,16 +109,16 @@ static const keymap_t keys[] = {
{ false, XK_minus, i_zoom, (arg_t) -1 },
{ false, XK_KP_Subtract, i_zoom, (arg_t) -1 },
{ false, XK_equal, i_set_zoom, (arg_t) 100 },
- { false, XK_w, i_fit_to_win, (arg_t) None },
+ { false, XK_w, i_fit_to_win, (arg_t) SCALE_FIT },
+ { false, XK_e, i_fit_to_win, (arg_t) SCALE_WIDTH },
+ { false, XK_E, i_fit_to_win, (arg_t) SCALE_HEIGHT },
{ false, XK_W, i_fit_to_img, (arg_t) None },
{ false, XK_less, i_rotate, (arg_t) DIR_LEFT },
{ false, XK_greater, i_rotate, (arg_t) DIR_RIGHT },
- { false, XK_s, i_toggle_slideshow, (arg_t) None },
- { true, XK_plus, i_adjust_slideshow, (arg_t) +1 },
- { true, XK_minus, i_adjust_slideshow, (arg_t) -1 },
- { true, XK_equal, i_reset_slideshow, (arg_t) None },
+ { false, XK_backslash, i_flip, (arg_t) FLIP_HORIZONTAL },
+ { false, XK_bar, i_flip, (arg_t) FLIP_VERTICAL },
{ false, XK_a, i_toggle_antialias, (arg_t) None },
{ false, XK_A, it_toggle_alpha, (arg_t) None },